### March 2025

- Omnibenchmark was part of the _Modern Benchmarking_ conference in Ascona, Swizerland:
  - [Omnibenchmark for continuous and open benchmarking (poster)](https://zenodo.org/records/15105274)
  - [How to build a continuous benchmarking ecosystem in bioinformatics? (poster)](https://zenodo.org/records/15112490)
  - [From solo to community benchmarking (slides)](https://zenodo.org/records/15112402)

### January 2025

- Release candidate [v0.1.0-rc.3](https://github.com/omnibenchmark/omnibenchmark/releases/tag/v0.1.0-rc.3)

### December 2024

- Release candidate [v0.1.0-rc.2](https://github.com/omnibenchmark/omnibenchmark/releases/tag/v0.1.0-rc.2)

### September 2024

- Release candidate [v0.1.0-rc.1](https://github.com/omnibenchmark/omnibenchmark/releases/tag/v0.1.0-rc.1)
- Preprint [Omnibenchmark (alpha) for continuous and open benchmarking in bioinformatics](https://arxiv.org/abs/2409.17038)
- Preprint [Building a continuous benchmarking ecosystem in bioinformatics](https://arxiv.org/abs/2409.15472)

